@@ -158,3 +158,27 @@ class TestAdvancedImages(TestCase):
             """![Image](http://humane man.jpg)""",
             """<p><img alt="Image" src="http://humane man.jpg" /></p>"""
         )
+
+    def test_short_ref(self):
+        self.assertMarkdownRenders(
+            self.dedent(
+                """
+                ![ref]
+
+                [ref]: ./image.jpg
+                """
+            ),
+            '<p><img alt="ref" src="./image.jpg" /></p>'
+        )
+
+    def test_short_ref_in_link(self):
+        self.assertMarkdownRenders(
+            self.dedent(
+                """
+                [![img ref]](http://example.com/)
+
+                [img ref]: ./image.jpg
+                """
+            ),
+            '<p><a href="http://example.com/"><img alt="img ref" src="./image.jpg" /></a></p>'
+        )
